#
# spec file for package python-precis-i18n
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   precis_i18n
Name:           python-precis-i18n
Version:        1.1.0
Release:        1.5
Summary:        Internationalised Usernames and Passwords
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/byllyfish/precis_i18n
Source:         https://github.com/byllyfish/precis_i18n/archive/v%{version}.tar.gz#/%{_name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-unicodedata2
BuildArch:      noarch
Provides:       python-%{_name} = %{version}-%{release}
%python_subpackages

%description
The PRECIS framework makes internationalised user names and
passwords safer for use by applications. PRECIS profiles transform
unicode strings into a canonical form, suitable for comparison.

This module implements the PRECIS Framework as described in:
 - PRECIS Framework: Preparation, Enforcement, and Comparison of
   Internationalized Strings in Application Protocols (RFC 8264).
 - Preparation, Enforcement, and Comparison of Internationalized
   Strings Representing Usernames and Passwords (RFC 8265).
 - Preparation, Enforcement, and Comparison of Internationalized
   Strings Representing Nicknames (RFC 8266).

%prep
%autosetup -n %{_name}-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/

%check
%pyunittest -v

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{python_sitelib}/%{_name}/
%{python_sitelib}/%{_name}-%{version}.dist-info

%changelog
* Wed Dec 27 2023 Ben Greiner <code@bnavigator.de>
- Update specfile for PEP517 and python packaging best practices
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Fixed an issue in the Nickname profile implementation that
    trimmed extra leading/trailing white space beyond the `Zs`
    category prescribed in RFC 8266. Python treats certain
    Unicode control characters as white space. If these appeared
    as leading/trailing spaces in a Nickname string, they
    were stripped. With this release, the Nickname profile will
    raise a UnicodeEncodeError `DISALLOWED/controls` if any control
    characters are encountered. (Issue #29)
  * Update internal tables for Unicode 15.1.
  * Change format of README and CHANGELOG files to Markdown.
  * Drop support for Python 3.3 and 3.4.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.5:
  * Update internal tables for Unicode 15.0.
  * Small type hint fix to one ``.pyi`` file.
  * Add Python 3.11 and 3.12 to CI build environment.
  * Update copyright year (2023).
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Update internal tables for Unicode 14.0. These updates also affect context
  rules for Unicode 11.0 through 13.0.
  * In limited cases under previous versions of precis_i18n, valid strings under
  Unicode 11.0-13.0 were erroneously DISALLOWED due to context reasons
  hebrew_punctuation, katakana_middle_dot, and zero_width_nonjoiner. (Issue #19)
  * Add type hints for package
* Sun May  2 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.3
  * MANIFEST.in excludes test_derived_props_files.py; test data
    files are not packaged.
  * CI script now builds source package and runs tests from it.
  * Use Github Actions for continuous integration.
  * Update copyright year (2021).
- Release 1.0.2
  * get_profile now supports alternative unicodedata2 module
    (Issue #8).
  * get_profile maps ':' to '_' before looking up profile name
    (Issue #10).
  * Test Unicode 12.1 for Python 3.8.
  * Test Unicode 12.0 (Using optional unicodedata2 module)
  * Test Unicode 13.0 for Python 3.9 (Issue #9).
  Update copyright year (2020).
- Drop support_unicode_12.1_for_python_3.8.patch
* Wed Mar 11 2020 Benoît Monin <benoit.monin@gmx.fr>
- add support_unicode_12.1_for_python_3.8.patch to fix test under
  python 3.8
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.1:
  * Fixed a dict/set syntax typo that has no runtime effect (6ae6876).
  * Test forward compatibility of derived props test files as Unicode version increases.
  * Test Unicode 11.0 (Python 3.7).
- Switch to github tarball for all test fixtures
* Mon Nov 19 2018 sor.alexei@meowr.ru
- Initial package.
